@import "weather-icons-core.scss";
@import "icon-variables/variables-wind-names.scss";
@import "icon-classes/classes-wind.scss";
@import "icon-classes/classes-wind-degrees.scss";
@import "icon-classes/classes-wind-aliases.scss";
